nuseds_enumeration_method_crosswalk
nuseds_enumeration_method_crosswalk()Return the curated NuSEDS enumeration-method crosswalk.
Returns
| Name | Type | Description |
|---|---|---|
| pandas.DataFrame | Legacy value, method family, candidate ontology term, and review notes. |
Return the curated NuSEDS enumeration-method crosswalk.
| Name | Type | Description |
|---|---|---|
| pandas.DataFrame | Legacy value, method family, candidate ontology term, and review notes. |