nuseds_estimate_method_crosswalk
nuseds_estimate_method_crosswalk()Return the curated NuSEDS estimate-method crosswalk.
Returns
| Name | Type | Description |
|---|---|---|
| pandas.DataFrame | Legacy value, method family, interpretation, ontology term, and notes. |
Return the curated NuSEDS estimate-method crosswalk.
| Name | Type | Description |
|---|---|---|
| pandas.DataFrame | Legacy value, method family, interpretation, ontology term, and notes. |