suggest_facet_schemes

suggest_facet_schemes(proposed_terms)

Analyze proposed terms and suggest facet schemes instead of proliferating individual terms.

Identifies patterns indicating when constraint schemes (age class, life phase, etc.) should be created rather than creating many individual terms.

Parameters

Name Type Description Default
proposed_terms pd.DataFrame DataFrame with term_label column required

Returns

Name Type Description
pd.DataFrame Suggested facet schemes with columns: - scheme_name: Name of the proposed scheme - scheme_definition: Description of the scheme - suggested_concepts: List of concepts for this scheme

Examples

>>> proposed = pd.read_csv("work/semantics/gpt_proposed_terms.csv")
>>> facets = suggest_facet_schemes(proposed)
>>> print(facets)
Back to top